"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.connector_event import ConnectorEvent
from apideck.model.connector_oauth_scopes1 import ConnectorOauthScopes1
from apideck.model.linked_connector_resource import LinkedConnectorResource
from apideck.model.unified_api_id import UnifiedApiId
globals()['ConnectorEvent'] = ConnectorEvent
globals()['ConnectorOauthScopes1'] = ConnectorOauthScopes1
globals()['LinkedConnectorResource'] = LinkedConnectorResource
globals()['UnifiedApiId'] = UnifiedApiId
from apideck.model.connector_unified_apis import ConnectorUnifiedApis


class TestConnectorUnifiedApis(unittest.TestCase):
    """ConnectorUnifiedApis unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConnectorUnifiedApis(self):
        """Test ConnectorUnifiedApis"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConnectorUnifiedApis()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
