"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.accounting_event_type import AccountingEventType


class TestAccountingEventType(unittest.TestCase):
    """AccountingEventType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccountingEventType(self):
        """Test AccountingEventType"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AccountingEventType()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
