"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.pos_api import PosApi  # noqa: E501


class TestPosApi(unittest.TestCase):
    """PosApi unit test stubs"""

    def setUp(self):
        self.api = PosApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_items_add(self):
        """Test case for items_add

        Create Item  # noqa: E501
        """
        pass

    def test_items_all(self):
        """Test case for items_all

        List Items  # noqa: E501
        """
        pass

    def test_items_delete(self):
        """Test case for items_delete

        Delete Item  # noqa: E501
        """
        pass

    def test_items_one(self):
        """Test case for items_one

        Get Item  # noqa: E501
        """
        pass

    def test_items_update(self):
        """Test case for items_update

        Update Item  # noqa: E501
        """
        pass

    def test_locations_add(self):
        """Test case for locations_add

        Create Location  # noqa: E501
        """
        pass

    def test_locations_all(self):
        """Test case for locations_all

        List Locations  # noqa: E501
        """
        pass

    def test_locations_delete(self):
        """Test case for locations_delete

        Delete Location  # noqa: E501
        """
        pass

    def test_locations_one(self):
        """Test case for locations_one

        Get Location  # noqa: E501
        """
        pass

    def test_locations_update(self):
        """Test case for locations_update

        Update Location  # noqa: E501
        """
        pass

    def test_merchants_add(self):
        """Test case for merchants_add

        Create Merchant  # noqa: E501
        """
        pass

    def test_merchants_all(self):
        """Test case for merchants_all

        List Merchants  # noqa: E501
        """
        pass

    def test_merchants_delete(self):
        """Test case for merchants_delete

        Delete Merchant  # noqa: E501
        """
        pass

    def test_merchants_one(self):
        """Test case for merchants_one

        Get Merchant  # noqa: E501
        """
        pass

    def test_merchants_update(self):
        """Test case for merchants_update

        Update Merchant  # noqa: E501
        """
        pass

    def test_modifier_groups_add(self):
        """Test case for modifier_groups_add

        Create Modifier Group  # noqa: E501
        """
        pass

    def test_modifier_groups_all(self):
        """Test case for modifier_groups_all

        List Modifier Groups  # noqa: E501
        """
        pass

    def test_modifier_groups_delete(self):
        """Test case for modifier_groups_delete

        Delete Modifier Group  # noqa: E501
        """
        pass

    def test_modifier_groups_one(self):
        """Test case for modifier_groups_one

        Get Modifier Group  # noqa: E501
        """
        pass

    def test_modifier_groups_update(self):
        """Test case for modifier_groups_update

        Update Modifier Group  # noqa: E501
        """
        pass

    def test_modifiers_add(self):
        """Test case for modifiers_add

        Create Modifier  # noqa: E501
        """
        pass

    def test_modifiers_all(self):
        """Test case for modifiers_all

        List Modifiers  # noqa: E501
        """
        pass

    def test_modifiers_delete(self):
        """Test case for modifiers_delete

        Delete Modifier  # noqa: E501
        """
        pass

    def test_modifiers_one(self):
        """Test case for modifiers_one

        Get Modifier  # noqa: E501
        """
        pass

    def test_modifiers_update(self):
        """Test case for modifiers_update

        Update Modifier  # noqa: E501
        """
        pass

    def test_order_types_add(self):
        """Test case for order_types_add

        Create Order Type  # noqa: E501
        """
        pass

    def test_order_types_all(self):
        """Test case for order_types_all

        List Order Types  # noqa: E501
        """
        pass

    def test_order_types_delete(self):
        """Test case for order_types_delete

        Delete Order Type  # noqa: E501
        """
        pass

    def test_order_types_one(self):
        """Test case for order_types_one

        Get Order Type  # noqa: E501
        """
        pass

    def test_order_types_update(self):
        """Test case for order_types_update

        Update Order Type  # noqa: E501
        """
        pass

    def test_orders_add(self):
        """Test case for orders_add

        Create Order  # noqa: E501
        """
        pass

    def test_orders_all(self):
        """Test case for orders_all

        List Orders  # noqa: E501
        """
        pass

    def test_orders_delete(self):
        """Test case for orders_delete

        Delete Order  # noqa: E501
        """
        pass

    def test_orders_one(self):
        """Test case for orders_one

        Get Order  # noqa: E501
        """
        pass

    def test_orders_pay(self):
        """Test case for orders_pay

        Pay Order  # noqa: E501
        """
        pass

    def test_orders_update(self):
        """Test case for orders_update

        Update Order  # noqa: E501
        """
        pass

    def test_payments_add(self):
        """Test case for payments_add

        Create Payment  # noqa: E501
        """
        pass

    def test_payments_all(self):
        """Test case for payments_all

        List Payments  # noqa: E501
        """
        pass

    def test_payments_delete(self):
        """Test case for payments_delete

        Delete Payment  # noqa: E501
        """
        pass

    def test_payments_one(self):
        """Test case for payments_one

        Get Payment  # noqa: E501
        """
        pass

    def test_payments_update(self):
        """Test case for payments_update

        Update Payment  # noqa: E501
        """
        pass

    def test_tenders_add(self):
        """Test case for tenders_add

        Create Tender  # noqa: E501
        """
        pass

    def test_tenders_all(self):
        """Test case for tenders_all

        List Tenders  # noqa: E501
        """
        pass

    def test_tenders_delete(self):
        """Test case for tenders_delete

        Delete Tender  # noqa: E501
        """
        pass

    def test_tenders_one(self):
        """Test case for tenders_one

        Get Tender  # noqa: E501
        """
        pass

    def test_tenders_update(self):
        """Test case for tenders_update

        Update Tender  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
