"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.ats_api import AtsApi  # noqa: E501


class TestAtsApi(unittest.TestCase):
    """AtsApi unit test stubs"""

    def setUp(self):
        self.api = AtsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_applicants_add(self):
        """Test case for applicants_add

        Create Applicant  # noqa: E501
        """
        pass

    def test_applicants_all(self):
        """Test case for applicants_all

        List Applicants  # noqa: E501
        """
        pass

    def test_applicants_delete(self):
        """Test case for applicants_delete

        Delete Applicant  # noqa: E501
        """
        pass

    def test_applicants_one(self):
        """Test case for applicants_one

        Get Applicant  # noqa: E501
        """
        pass

    def test_applicants_update(self):
        """Test case for applicants_update

        Update Applicant  # noqa: E501
        """
        pass

    def test_applications_add(self):
        """Test case for applications_add

        Create Application  # noqa: E501
        """
        pass

    def test_applications_all(self):
        """Test case for applications_all

        List Applications  # noqa: E501
        """
        pass

    def test_applications_delete(self):
        """Test case for applications_delete

        Delete Application  # noqa: E501
        """
        pass

    def test_applications_one(self):
        """Test case for applications_one

        Get Application  # noqa: E501
        """
        pass

    def test_applications_update(self):
        """Test case for applications_update

        Update Application  # noqa: E501
        """
        pass

    def test_jobs_all(self):
        """Test case for jobs_all

        List Jobs  # noqa: E501
        """
        pass

    def test_jobs_one(self):
        """Test case for jobs_one

        Get Job  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
