"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.connector_api import ConnectorApi  # noqa: E501


class TestConnectorApi(unittest.TestCase):
    """ConnectorApi unit test stubs"""

    def setUp(self):
        self.api = ConnectorApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_resource_coverage_one(self):
        """Test case for api_resource_coverage_one

        Get API Resource Coverage  # noqa: E501
        """
        pass

    def test_api_resources_one(self):
        """Test case for api_resources_one

        Get API Resource  # noqa: E501
        """
        pass

    def test_apis_all(self):
        """Test case for apis_all

        List APIs  # noqa: E501
        """
        pass

    def test_apis_one(self):
        """Test case for apis_one

        Get API  # noqa: E501
        """
        pass

    def test_connector_docs_one(self):
        """Test case for connector_docs_one

        Get Connector Doc content  # noqa: E501
        """
        pass

    def test_connector_resources_one(self):
        """Test case for connector_resources_one

        Get Connector Resource  # noqa: E501
        """
        pass

    def test_connectors_all(self):
        """Test case for connectors_all

        List Connectors  # noqa: E501
        """
        pass

    def test_connectors_one(self):
        """Test case for connectors_one

        Get Connector  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
