# flake8: noqa

"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from apideck.api_client import ApiClient

# import Configuration
from apideck.configuration import Configuration

# import exceptions
from apideck.exceptions import OpenApiException
from apideck.exceptions import ApiAttributeError
from apideck.exceptions import ApiTypeError
from apideck.exceptions import ApiValueError
from apideck.exceptions import ApiKeyError
from apideck.exceptions import ApiException
