"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import apideck
from apideck.model.profit_and_loss_expenses import ProfitAndLossExpenses
from apideck.model.profit_and_loss_gross_profit import ProfitAndLossGrossProfit
from apideck.model.profit_and_loss_income import ProfitAndLossIncome
from apideck.model.profit_and_loss_net_income import ProfitAndLossNetIncome
from apideck.model.profit_and_loss_net_operating_income import ProfitAndLossNetOperatingIncome
globals()['ProfitAndLossExpenses'] = ProfitAndLossExpenses
globals()['ProfitAndLossGrossProfit'] = ProfitAndLossGrossProfit
globals()['ProfitAndLossIncome'] = ProfitAndLossIncome
globals()['ProfitAndLossNetIncome'] = ProfitAndLossNetIncome
globals()['ProfitAndLossNetOperatingIncome'] = ProfitAndLossNetOperatingIncome
from apideck.model.profit_and_loss import ProfitAndLoss


class TestProfitAndLoss(unittest.TestCase):
    """ProfitAndLoss unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProfitAndLoss(self):
        """Test ProfitAndLoss"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ProfitAndLoss()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
