"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.file_storage_api import FileStorageApi  # noqa: E501


class TestFileStorageApi(unittest.TestCase):
    """FileStorageApi unit test stubs"""

    def setUp(self):
        self.api = FileStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_drive_groups_add(self):
        """Test case for drive_groups_add

        Create DriveGroup  # noqa: E501
        """
        pass

    def test_drive_groups_all(self):
        """Test case for drive_groups_all

        List DriveGroups  # noqa: E501
        """
        pass

    def test_drive_groups_delete(self):
        """Test case for drive_groups_delete

        Delete DriveGroup  # noqa: E501
        """
        pass

    def test_drive_groups_one(self):
        """Test case for drive_groups_one

        Get DriveGroup  # noqa: E501
        """
        pass

    def test_drive_groups_update(self):
        """Test case for drive_groups_update

        Update DriveGroup  # noqa: E501
        """
        pass

    def test_drives_add(self):
        """Test case for drives_add

        Create Drive  # noqa: E501
        """
        pass

    def test_drives_all(self):
        """Test case for drives_all

        List Drives  # noqa: E501
        """
        pass

    def test_drives_delete(self):
        """Test case for drives_delete

        Delete Drive  # noqa: E501
        """
        pass

    def test_drives_one(self):
        """Test case for drives_one

        Get Drive  # noqa: E501
        """
        pass

    def test_drives_update(self):
        """Test case for drives_update

        Update Drive  # noqa: E501
        """
        pass

    def test_files_all(self):
        """Test case for files_all

        List Files  # noqa: E501
        """
        pass

    def test_files_delete(self):
        """Test case for files_delete

        Delete File  # noqa: E501
        """
        pass

    def test_files_download(self):
        """Test case for files_download

        Download File  # noqa: E501
        """
        pass

    def test_files_export(self):
        """Test case for files_export

        Export File  # noqa: E501
        """
        pass

    def test_files_one(self):
        """Test case for files_one

        Get File  # noqa: E501
        """
        pass

    def test_files_search(self):
        """Test case for files_search

        Search Files  # noqa: E501
        """
        pass

    def test_files_update(self):
        """Test case for files_update

        Rename or move File  # noqa: E501
        """
        pass

    def test_folders_add(self):
        """Test case for folders_add

        Create Folder  # noqa: E501
        """
        pass

    def test_folders_copy(self):
        """Test case for folders_copy

        Copy Folder  # noqa: E501
        """
        pass

    def test_folders_delete(self):
        """Test case for folders_delete

        Delete Folder  # noqa: E501
        """
        pass

    def test_folders_one(self):
        """Test case for folders_one

        Get Folder  # noqa: E501
        """
        pass

    def test_folders_update(self):
        """Test case for folders_update

        Rename or move Folder  # noqa: E501
        """
        pass

    def test_shared_links_add(self):
        """Test case for shared_links_add

        Create Shared Link  # noqa: E501
        """
        pass

    def test_shared_links_all(self):
        """Test case for shared_links_all

        List SharedLinks  # noqa: E501
        """
        pass

    def test_shared_links_delete(self):
        """Test case for shared_links_delete

        Delete Shared Link  # noqa: E501
        """
        pass

    def test_shared_links_one(self):
        """Test case for shared_links_one

        Get Shared Link  # noqa: E501
        """
        pass

    def test_shared_links_update(self):
        """Test case for shared_links_update

        Update Shared Link  # noqa: E501
        """
        pass

    def test_upload_sessions_add(self):
        """Test case for upload_sessions_add

        Start Upload Session  # noqa: E501
        """
        pass

    def test_upload_sessions_delete(self):
        """Test case for upload_sessions_delete

        Abort Upload Session  # noqa: E501
        """
        pass

    def test_upload_sessions_finish(self):
        """Test case for upload_sessions_finish

        Finish Upload Session  # noqa: E501
        """
        pass

    def test_upload_sessions_one(self):
        """Test case for upload_sessions_one

        Get Upload Session  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
