"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.hris_api import HrisApi  # noqa: E501


class TestHrisApi(unittest.TestCase):
    """HrisApi unit test stubs"""

    def setUp(self):
        self.api = HrisApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_companies_add(self):
        """Test case for companies_add

        Create Company  # noqa: E501
        """
        pass

    def test_companies_all(self):
        """Test case for companies_all

        List Companies  # noqa: E501
        """
        pass

    def test_companies_delete(self):
        """Test case for companies_delete

        Delete Company  # noqa: E501
        """
        pass

    def test_companies_one(self):
        """Test case for companies_one

        Get Company  # noqa: E501
        """
        pass

    def test_companies_update(self):
        """Test case for companies_update

        Update Company  # noqa: E501
        """
        pass

    def test_departments_add(self):
        """Test case for departments_add

        Create Department  # noqa: E501
        """
        pass

    def test_departments_all(self):
        """Test case for departments_all

        List Departments  # noqa: E501
        """
        pass

    def test_departments_delete(self):
        """Test case for departments_delete

        Delete Department  # noqa: E501
        """
        pass

    def test_departments_one(self):
        """Test case for departments_one

        Get Department  # noqa: E501
        """
        pass

    def test_departments_update(self):
        """Test case for departments_update

        Update Department  # noqa: E501
        """
        pass

    def test_employee_payrolls_all(self):
        """Test case for employee_payrolls_all

        List Employee Payrolls  # noqa: E501
        """
        pass

    def test_employee_payrolls_one(self):
        """Test case for employee_payrolls_one

        Get Employee Payroll  # noqa: E501
        """
        pass

    def test_employee_schedules_all(self):
        """Test case for employee_schedules_all

        List Employee Schedules  # noqa: E501
        """
        pass

    def test_employees_add(self):
        """Test case for employees_add

        Create Employee  # noqa: E501
        """
        pass

    def test_employees_all(self):
        """Test case for employees_all

        List Employees  # noqa: E501
        """
        pass

    def test_employees_delete(self):
        """Test case for employees_delete

        Delete Employee  # noqa: E501
        """
        pass

    def test_employees_one(self):
        """Test case for employees_one

        Get Employee  # noqa: E501
        """
        pass

    def test_employees_update(self):
        """Test case for employees_update

        Update Employee  # noqa: E501
        """
        pass

    def test_payrolls_all(self):
        """Test case for payrolls_all

        List Payroll  # noqa: E501
        """
        pass

    def test_payrolls_one(self):
        """Test case for payrolls_one

        Get Payroll  # noqa: E501
        """
        pass

    def test_time_off_requests_add(self):
        """Test case for time_off_requests_add

        Create Time Off Request  # noqa: E501
        """
        pass

    def test_time_off_requests_all(self):
        """Test case for time_off_requests_all

        List Time Off Requests  # noqa: E501
        """
        pass

    def test_time_off_requests_delete(self):
        """Test case for time_off_requests_delete

        Delete Time Off Request  # noqa: E501
        """
        pass

    def test_time_off_requests_one(self):
        """Test case for time_off_requests_one

        Get Time Off Request  # noqa: E501
        """
        pass

    def test_time_off_requests_update(self):
        """Test case for time_off_requests_update

        Update Time Off Request  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
