"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.accounting_api import AccountingApi  # noqa: E501


class TestAccountingApi(unittest.TestCase):
    """AccountingApi unit test stubs"""

    def setUp(self):
        self.api = AccountingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_balance_sheet_one(self):
        """Test case for balance_sheet_one

        Get BalanceSheet  # noqa: E501
        """
        pass

    def test_bills_add(self):
        """Test case for bills_add

        Create Bill  # noqa: E501
        """
        pass

    def test_bills_all(self):
        """Test case for bills_all

        List Bills  # noqa: E501
        """
        pass

    def test_bills_delete(self):
        """Test case for bills_delete

        Delete Bill  # noqa: E501
        """
        pass

    def test_bills_one(self):
        """Test case for bills_one

        Get Bill  # noqa: E501
        """
        pass

    def test_bills_update(self):
        """Test case for bills_update

        Update Bill  # noqa: E501
        """
        pass

    def test_company_info_one(self):
        """Test case for company_info_one

        Get company info  # noqa: E501
        """
        pass

    def test_credit_notes_add(self):
        """Test case for credit_notes_add

        Create Credit Note  # noqa: E501
        """
        pass

    def test_credit_notes_all(self):
        """Test case for credit_notes_all

        List Credit Notes  # noqa: E501
        """
        pass

    def test_credit_notes_delete(self):
        """Test case for credit_notes_delete

        Delete Credit Note  # noqa: E501
        """
        pass

    def test_credit_notes_one(self):
        """Test case for credit_notes_one

        Get Credit Note  # noqa: E501
        """
        pass

    def test_credit_notes_update(self):
        """Test case for credit_notes_update

        Update Credit Note  # noqa: E501
        """
        pass

    def test_customers_add(self):
        """Test case for customers_add

        Create Customer  # noqa: E501
        """
        pass

    def test_customers_all(self):
        """Test case for customers_all

        List Customers  # noqa: E501
        """
        pass

    def test_customers_delete(self):
        """Test case for customers_delete

        Delete Customer  # noqa: E501
        """
        pass

    def test_customers_one(self):
        """Test case for customers_one

        Get Customer  # noqa: E501
        """
        pass

    def test_customers_update(self):
        """Test case for customers_update

        Update Customer  # noqa: E501
        """
        pass

    def test_invoice_items_add(self):
        """Test case for invoice_items_add

        Create Invoice Item  # noqa: E501
        """
        pass

    def test_invoice_items_all(self):
        """Test case for invoice_items_all

        List Invoice Items  # noqa: E501
        """
        pass

    def test_invoice_items_delete(self):
        """Test case for invoice_items_delete

        Delete Invoice Item  # noqa: E501
        """
        pass

    def test_invoice_items_one(self):
        """Test case for invoice_items_one

        Get Invoice Item  # noqa: E501
        """
        pass

    def test_invoice_items_update(self):
        """Test case for invoice_items_update

        Update Invoice Item  # noqa: E501
        """
        pass

    def test_invoices_add(self):
        """Test case for invoices_add

        Create Invoice  # noqa: E501
        """
        pass

    def test_invoices_all(self):
        """Test case for invoices_all

        List Invoices  # noqa: E501
        """
        pass

    def test_invoices_delete(self):
        """Test case for invoices_delete

        Delete Invoice  # noqa: E501
        """
        pass

    def test_invoices_one(self):
        """Test case for invoices_one

        Get Invoice  # noqa: E501
        """
        pass

    def test_invoices_update(self):
        """Test case for invoices_update

        Update Invoice  # noqa: E501
        """
        pass

    def test_journal_entries_add(self):
        """Test case for journal_entries_add

        Create Journal Entry  # noqa: E501
        """
        pass

    def test_journal_entries_all(self):
        """Test case for journal_entries_all

        List Journal Entries  # noqa: E501
        """
        pass

    def test_journal_entries_delete(self):
        """Test case for journal_entries_delete

        Delete Journal Entry  # noqa: E501
        """
        pass

    def test_journal_entries_one(self):
        """Test case for journal_entries_one

        Get Journal Entry  # noqa: E501
        """
        pass

    def test_journal_entries_update(self):
        """Test case for journal_entries_update

        Update Journal Entry  # noqa: E501
        """
        pass

    def test_ledger_accounts_add(self):
        """Test case for ledger_accounts_add

        Create Ledger Account  # noqa: E501
        """
        pass

    def test_ledger_accounts_all(self):
        """Test case for ledger_accounts_all

        List Ledger Accounts  # noqa: E501
        """
        pass

    def test_ledger_accounts_delete(self):
        """Test case for ledger_accounts_delete

        Delete Ledger Account  # noqa: E501
        """
        pass

    def test_ledger_accounts_one(self):
        """Test case for ledger_accounts_one

        Get Ledger Account  # noqa: E501
        """
        pass

    def test_ledger_accounts_update(self):
        """Test case for ledger_accounts_update

        Update Ledger Account  # noqa: E501
        """
        pass

    def test_payments_add(self):
        """Test case for payments_add

        Create Payment  # noqa: E501
        """
        pass

    def test_payments_all(self):
        """Test case for payments_all

        List Payments  # noqa: E501
        """
        pass

    def test_payments_delete(self):
        """Test case for payments_delete

        Delete Payment  # noqa: E501
        """
        pass

    def test_payments_one(self):
        """Test case for payments_one

        Get Payment  # noqa: E501
        """
        pass

    def test_payments_update(self):
        """Test case for payments_update

        Update Payment  # noqa: E501
        """
        pass

    def test_profit_and_loss_one(self):
        """Test case for profit_and_loss_one

        Get Profit and Loss  # noqa: E501
        """
        pass

    def test_purchase_orders_add(self):
        """Test case for purchase_orders_add

        Create Purchase Order  # noqa: E501
        """
        pass

    def test_purchase_orders_all(self):
        """Test case for purchase_orders_all

        List Purchase Orders  # noqa: E501
        """
        pass

    def test_purchase_orders_delete(self):
        """Test case for purchase_orders_delete

        Delete Purchase Order  # noqa: E501
        """
        pass

    def test_purchase_orders_one(self):
        """Test case for purchase_orders_one

        Get Purchase Order  # noqa: E501
        """
        pass

    def test_purchase_orders_update(self):
        """Test case for purchase_orders_update

        Update Purchase Order  # noqa: E501
        """
        pass

    def test_suppliers_add(self):
        """Test case for suppliers_add

        Create Supplier  # noqa: E501
        """
        pass

    def test_suppliers_all(self):
        """Test case for suppliers_all

        List Suppliers  # noqa: E501
        """
        pass

    def test_suppliers_delete(self):
        """Test case for suppliers_delete

        Delete Supplier  # noqa: E501
        """
        pass

    def test_suppliers_one(self):
        """Test case for suppliers_one

        Get Supplier  # noqa: E501
        """
        pass

    def test_suppliers_update(self):
        """Test case for suppliers_update

        Update Supplier  # noqa: E501
        """
        pass

    def test_tax_rates_add(self):
        """Test case for tax_rates_add

        Create Tax Rate  # noqa: E501
        """
        pass

    def test_tax_rates_all(self):
        """Test case for tax_rates_all

        List Tax Rates  # noqa: E501
        """
        pass

    def test_tax_rates_delete(self):
        """Test case for tax_rates_delete

        Delete Tax Rate  # noqa: E501
        """
        pass

    def test_tax_rates_one(self):
        """Test case for tax_rates_one

        Get Tax Rate  # noqa: E501
        """
        pass

    def test_tax_rates_update(self):
        """Test case for tax_rates_update

        Update Tax Rate  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
