"""
    Apideck

    The Apideck OpenAPI Spec: SDK Optimized  # noqa: E501

    The version of the OpenAPI document: 10.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import apideck
from apideck.api.crm_api import CrmApi  # noqa: E501


class TestCrmApi(unittest.TestCase):
    """CrmApi unit test stubs"""

    def setUp(self):
        self.api = CrmApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activities_add(self):
        """Test case for activities_add

        Create activity  # noqa: E501
        """
        pass

    def test_activities_all(self):
        """Test case for activities_all

        List activities  # noqa: E501
        """
        pass

    def test_activities_delete(self):
        """Test case for activities_delete

        Delete activity  # noqa: E501
        """
        pass

    def test_activities_one(self):
        """Test case for activities_one

        Get activity  # noqa: E501
        """
        pass

    def test_activities_update(self):
        """Test case for activities_update

        Update activity  # noqa: E501
        """
        pass

    def test_companies_add(self):
        """Test case for companies_add

        Create company  # noqa: E501
        """
        pass

    def test_companies_all(self):
        """Test case for companies_all

        List companies  # noqa: E501
        """
        pass

    def test_companies_delete(self):
        """Test case for companies_delete

        Delete company  # noqa: E501
        """
        pass

    def test_companies_one(self):
        """Test case for companies_one

        Get company  # noqa: E501
        """
        pass

    def test_companies_update(self):
        """Test case for companies_update

        Update company  # noqa: E501
        """
        pass

    def test_contacts_add(self):
        """Test case for contacts_add

        Create contact  # noqa: E501
        """
        pass

    def test_contacts_all(self):
        """Test case for contacts_all

        List contacts  # noqa: E501
        """
        pass

    def test_contacts_delete(self):
        """Test case for contacts_delete

        Delete contact  # noqa: E501
        """
        pass

    def test_contacts_one(self):
        """Test case for contacts_one

        Get contact  # noqa: E501
        """
        pass

    def test_contacts_update(self):
        """Test case for contacts_update

        Update contact  # noqa: E501
        """
        pass

    def test_leads_add(self):
        """Test case for leads_add

        Create lead  # noqa: E501
        """
        pass

    def test_leads_all(self):
        """Test case for leads_all

        List leads  # noqa: E501
        """
        pass

    def test_leads_delete(self):
        """Test case for leads_delete

        Delete lead  # noqa: E501
        """
        pass

    def test_leads_one(self):
        """Test case for leads_one

        Get lead  # noqa: E501
        """
        pass

    def test_leads_update(self):
        """Test case for leads_update

        Update lead  # noqa: E501
        """
        pass

    def test_notes_add(self):
        """Test case for notes_add

        Create note  # noqa: E501
        """
        pass

    def test_notes_all(self):
        """Test case for notes_all

        List notes  # noqa: E501
        """
        pass

    def test_notes_delete(self):
        """Test case for notes_delete

        Delete note  # noqa: E501
        """
        pass

    def test_notes_one(self):
        """Test case for notes_one

        Get note  # noqa: E501
        """
        pass

    def test_notes_update(self):
        """Test case for notes_update

        Update note  # noqa: E501
        """
        pass

    def test_opportunities_add(self):
        """Test case for opportunities_add

        Create opportunity  # noqa: E501
        """
        pass

    def test_opportunities_all(self):
        """Test case for opportunities_all

        List opportunities  # noqa: E501
        """
        pass

    def test_opportunities_delete(self):
        """Test case for opportunities_delete

        Delete opportunity  # noqa: E501
        """
        pass

    def test_opportunities_one(self):
        """Test case for opportunities_one

        Get opportunity  # noqa: E501
        """
        pass

    def test_opportunities_update(self):
        """Test case for opportunities_update

        Update opportunity  # noqa: E501
        """
        pass

    def test_pipelines_add(self):
        """Test case for pipelines_add

        Create pipeline  # noqa: E501
        """
        pass

    def test_pipelines_all(self):
        """Test case for pipelines_all

        List pipelines  # noqa: E501
        """
        pass

    def test_pipelines_delete(self):
        """Test case for pipelines_delete

        Delete pipeline  # noqa: E501
        """
        pass

    def test_pipelines_one(self):
        """Test case for pipelines_one

        Get pipeline  # noqa: E501
        """
        pass

    def test_pipelines_update(self):
        """Test case for pipelines_update

        Update pipeline  # noqa: E501
        """
        pass

    def test_users_add(self):
        """Test case for users_add

        Create user  # noqa: E501
        """
        pass

    def test_users_all(self):
        """Test case for users_all

        List users  # noqa: E501
        """
        pass

    def test_users_delete(self):
        """Test case for users_delete

        Delete user  # noqa: E501
        """
        pass

    def test_users_one(self):
        """Test case for users_one

        Get user  # noqa: E501
        """
        pass

    def test_users_update(self):
        """Test case for users_update

        Update user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
